@@ -133,18 +133,23 @@ class Api(snappi.Api):
                 pkt_headers = []
                 for i, header in enumerate(f['packet']):
 
+                    # ETHERNET HEADER FIELDS CONFIGURATION
                     if header['choice'] == 'ethernet':
                         pkt_headers.append(Ether())
                         layers.append('Ether')
-
-                        if header['ethernet']['src']['choice'] == 'value':
-                            pkt_headers[i].src = header['ethernet']['src']['value']
-
-                        if header['ethernet']['dst']['choice'] == 'value':
-                            pkt_headers[i].dst = header['ethernet']['dst']['value']
-                        
                         layerCnt['Ether'] = layerCnt['Ether']+1 if 'Ether' in layerCnt else 1
-                    
+
+                        if 'src' in header['ethernet']:
+                            vmCmds += ValueOptions.getMACValueCmds(
+                                'Ethernet', layerCnt['Ether'], header['ethernet']['src'], 'src', 0
+                            )
+
+                        if 'dst' in header['ethernet']:
+                            vmCmds += ValueOptions.getMACValueCmds(
+                                'Ethernet', layerCnt['Ether'], header['ethernet']['dst'], 'dst', 0
+                            )
+                        
+                        
                     # IPv4 HEADER FIELDS CONFIGURATION
                     elif header['choice'] == 'ipv4':
                         pkt_headers.append(IP())
@@ -161,12 +166,6 @@ class Api(snappi.Api):
                                 'IP', layerCnt['IP'], header['ipv4']['dst'], 32, 'dst', 0
                             )
 
-                        # if header['ipv4']['src']['choice'] == 'value':
-                        #     pkt_headers[i].src = header['ipv4']['src']['value']
-
-                        # if header['ipv4']['dst']['choice'] == 'value':
-                        #     pkt_headers[i].dst = header['ipv4']['dst']['value']
-
                     
                     # UDP HEADER FIELDS CONFIGURATION
                     elif header['choice'] == 'udp':
@@ -269,6 +268,8 @@ class Api(snappi.Api):
             self.c.disconnect()
             print(e)
 
+        return {'warnings': []}
+
 
     def set_transmit_state(self, payload):
         """Set the transmit state of flows
